=== modified file 'PetriEngine/AbstractPetriNetBuilder.h'
--- PetriEngine/AbstractPetriNetBuilder.h	2018-03-13 22:08:31 +0000
+++ PetriEngine/AbstractPetriNetBuilder.h	2018-05-12 15:14:12 +0000
@@ -46,8 +46,8 @@
                 double x = 0,
                 double y = 0)
         {
-            std::cout << "Colored places are not supported in standard P/T nets" << std::endl;
-            exit(-1);
+            std::cerr << "Colored places are not supported in standard P/T nets" << std::endl;
+            exit(ErrorCode);
         }
         /** Add a new transition with a unique name */
         virtual void addTransition(const std::string& name,
@@ -59,8 +59,8 @@
                 double x = 0,
                 double y = 0)
         {
-            std::cout << "Colored transitions are not supported in standard P/T nets" << std::endl;
-            exit(-1);
+            std::cerr << "Colored transitions are not supported in standard P/T nets" << std::endl;
+            exit(ErrorCode);
         }
         /** Add input arc with given weight */
         virtual void addInputArc(const std::string& place,
@@ -72,8 +72,8 @@
                 const std::string& transition,
                 Colored::ArcExpression_ptr expr)
         {
-            std::cout << "Colored input arcs are not supported in standard P/T nets" << std::endl;
-            exit(-1);
+            std::cerr << "Colored input arcs are not supported in standard P/T nets" << std::endl;
+            exit(ErrorCode);
         }
         /** Add output arc with given weight */
         virtual void addOutputArc(const std::string& transition,
@@ -84,15 +84,15 @@
                 const std::string& place,
                 Colored::ArcExpression_ptr expr)
         {
-            std::cout << "Colored output arcs are not supported in standard P/T nets" << std::endl;
-            exit(-1);
+            std::cerr << "Colored output arcs are not supported in standard P/T nets" << std::endl;
+            exit(ErrorCode);
         }
         /** Add color types with id */
         virtual void addColorType(const std::string& id,
                 Colored::ColorType* type)
         {
-            std::cout << "Color types are not supported in standard P/T nets" << std::endl;
-            exit(-1);
+            std::cerr << "Color types are not supported in standard P/T nets" << std::endl;
+            exit(ErrorCode);
         }
         
         virtual void enableColors() {

=== modified file 'PetriEngine/PQL/Expressions.cpp'
--- PetriEngine/PQL/Expressions.cpp	2018-05-12 14:04:35 +0000
+++ PetriEngine/PQL/Expressions.cpp	2018-05-12 15:14:12 +0000
@@ -19,6 +19,7 @@
  */
 #include "Contexts.h"
 #include "Expressions.h"
+#include "PetriEngine/errorcodes.h"
 
 #include <sstream>
 #include <assert.h>
@@ -3513,8 +3514,8 @@
         Condition_ptr UnfoldedUpperBoundsCondition::pushNegation(negstat_t&, const EvaluationContext& context, bool nested, bool negated, bool initrw) {
             if(negated)
             {
-                std::cout << "UPPER BOUNDS CANNOT BE NEGATED!" << std::endl;
-                exit(-1);
+                std::cerr << "UPPER BOUNDS CANNOT BE NEGATED!" << std::endl;
+                exit(ErrorCode);
             }
             return std::make_shared<UnfoldedUpperBoundsCondition>(_places, _max);
         }
@@ -3903,8 +3904,9 @@
             auto neg = _negated != other._negated;
             if(neg && other._constraints.size() > 1)
             {
-                std::cout << "MERGE OF CONJUNCT AND DISJUNCT NOT ALLOWED" << std::endl;
+                std::cerr << "MERGE OF CONJUNCT AND DISJUNCT NOT ALLOWED" << std::endl;
                 assert(false);
+                exit(ErrorCode);
             }
             auto il = _constraints.begin();
             for(auto& c : other._constraints)
@@ -3927,8 +3929,9 @@
                     }
                     else
                     {
-                        std::cout << "MERGE OF CONJUNCT AND DISJUNCT NOT ALLOWED" << std::endl;
+                        std::cerr << "MERGE OF CONJUNCT AND DISJUNCT NOT ALLOWED" << std::endl;
                         assert(false);
+                        exit(ErrorCode);
                     }
                     c2._place = c._place;
                     assert(c2._lower <= c2._upper);
@@ -4038,8 +4041,9 @@
                 }
                 else
                 {
-                    std::cout << "UNKNOWN " << std::endl;
+                    std::cerr << "UNKNOWN " << std::endl;
                     assert(false);
+                    exit(ErrorCode);
                 }
             }            
         }

=== modified file 'PetriEngine/Reachability/ReachabilitySearch.cpp'
--- PetriEngine/Reachability/ReachabilitySearch.cpp	2018-01-05 16:38:22 +0000
+++ PetriEngine/Reachability/ReachabilitySearch.cpp	2018-05-12 15:14:12 +0000
@@ -143,7 +143,8 @@
                     TRYREACH(RDFSQueue)
                     break;
                 default:
-                    std::cout << "UNSUPPORTED SEARCH STRATEGY" << std::endl;
+                    std::cerr << "UNSUPPORTED SEARCH STRATEGY" << std::endl;
+                    exit(ErrorCode);
             }
         }
     }

=== modified file 'PetriEngine/SuccessorGenerator.cpp'
--- PetriEngine/SuccessorGenerator.cpp	2018-02-22 16:42:37 +0000
+++ PetriEngine/SuccessorGenerator.cpp	2018-05-12 15:14:12 +0000
@@ -11,9 +11,11 @@
  * Created on 30 March 2016, 19:50
  */
 
-#include <cassert>
 #include "SuccessorGenerator.h"
 #include "Structures/State.h"
+#include "PetriEngine/errorcodes.h"
+
+#include <cassert>
 namespace PetriEngine {
 
     SuccessorGenerator::SuccessorGenerator(const PetriNet& net)
@@ -78,7 +80,7 @@
             n += _net._invariants[finv].tokens;
             if (n >= std::numeric_limits<uint32_t>::max()) {
                 std::cerr << "Exceeded 2**32 limit of tokens in a single place ("  << n << ")" << std::endl;
-                exit(-1);
+                exit(FailedCode);
             }
             write.marking()[_net._invariants[finv].place] = n;
         }

=== modified file 'PetriEngine/TAR/Renamer.h'
--- PetriEngine/TAR/Renamer.h	2018-03-28 11:57:09 +0000
+++ PetriEngine/TAR/Renamer.h	2018-05-12 15:14:12 +0000
@@ -97,7 +97,7 @@
                     default:
                         std::cerr << "UNKNOWN NODE TYPE" << std::endl;
                         assert(false);
-                        exit(-1);
+                        exit(ErrorCode);
                         break;
                 }              
                                

=== modified file 'PetriParse/PNMLParser.cpp'
--- PetriParse/PNMLParser.cpp	2018-05-11 11:15:49 +0000
+++ PetriParse/PNMLParser.cpp	2018-05-12 15:14:12 +0000
@@ -56,7 +56,7 @@
     rapidxml::xml_node<>* root = doc.first_node();
     if(strcmp(root->name(), "pnml") != 0)
     {
-        std::cout << "expecting <pnml> tag as root-node in xml tree." << std::endl;
+        std::cerr << "expecting <pnml> tag as root-node in xml tree." << std::endl;
         exit(ErrorCode);
     }
     
@@ -362,16 +362,16 @@
         } else if (strcmp(it->name(),"inhibitorArc") == 0) {
             parseArc(it, true);
         } else if (strcmp(it->name(), "variable") == 0) {
-            std::cout << "variable not supported" << std::endl;
-            exit(-1);
+            std::cerr << "variable not supported" << std::endl;
+            exit(ErrorCode);
         } else if (strcmp(it->name(),"queries") == 0) {
             parseQueries(it);
         } else if (strcmp(it->name(), "k-bound") == 0) {
-            std::cout << "k-bound should be given as command line option -k" << std::endl;
-            exit(-1);
+            std::cerr << "k-bound should be given as command line option -k" << std::endl;
+            exit(ErrorCode);
         } else if (strcmp(it->name(),"query") == 0) {
-            std::cout << "query tag not supported, please use PQL or XML-style queries instead" << std::endl;
-            exit(-1);            
+            std::cerr << "query tag not supported, please use PQL or XML-style queries instead" << std::endl;
+            exit(ErrorCode);            
         }
         else
         {
@@ -453,8 +453,8 @@
     auto type = element->first_attribute("type");
     if(type && strcmp(type->value(), "timed") == 0)
     {
-        std::cout << "timed arcs are not supported" << std::endl;
-        exit(-1);
+        std::cerr << "timed arcs are not supported" << std::endl;
+        exit(ErrorCode);
     }
     else if(type && strcmp(type->value(), "inhibitor") == 0)
     {
@@ -469,12 +469,14 @@
         if(std::find_if(text.begin(), text.end(), [](char c) { return !std::isdigit(c) && !std::isblank(c); }) != text.end())
         {
             if(weight == 0) weight = 1;
-            std::cerr << "WARNING: Found non-integer-text in inscription-tag (weight) on arc from " << source << " to " << target << " with value \"" << text << "\". An integer was expected. Using " << weight << " as weight." << std::endl;
+            std::cerr << "ERROR: Found non-integer-text in inscription-tag (weight) on arc from " << source << " to " << target << " with value \"" << text << "\". An integer was expected." << std::endl;
+            exit(ErrorCode);
         }
         assert(weight > 0);
         if(!first)
         {
-            std::cerr << "WARNING: Multiple inscription tags in xml of a arc from " << source << " to " << target << ". Using last found value" << std::endl;
+            std::cerr << "ERROR: Multiple inscription tags in xml of a arc from " << source << " to " << target << "." << std::endl;
+            exit(ErrorCode);
         }
         first = false;
     }
@@ -485,7 +487,8 @@
         expr = parseArcExpression(it->first_node("structure"));
         if(!first)
         {
-            std::cerr << "WARNING: Multiple hlinscription tags in xml of a arc from " << source << " to " << target << ". Using last found value" << std::endl;
+            std::cerr << "ERROR: Multiple hlinscription tags in xml of a arc from " << source << " to " << target << "." << std::endl;
+            exit(ErrorCode);            
         }
         first = false;
     }
@@ -500,8 +503,8 @@
     assert(weight > 0);
     
     if (inhibitor && isColored) {
-        std::cout << "inhibitor arcs are not supported in colored Petri nets" << std::endl;
-        exit(-1);
+        std::cerr << "inhibitor arcs are not supported in colored Petri nets" << std::endl;
+        exit(ErrorCode);
     }
     
     if(weight != 0)
@@ -517,7 +520,8 @@
     }
     else
     {
-        std::cerr << "WARNING: Ignoring arc from " << source << " to " << target << " with weight 0." << std::endl;            
+        std::cerr << "ERROR: Arc from " << source << " to " << target << " has non-sensible weight 0." << std::endl;         
+        exit(ErrorCode);
     }
 }
 
@@ -561,11 +565,11 @@
         } else if (strcmp(it->name(), "condition") == 0) {
             t.expr = parseGuardExpression(it->first_node("structure"));
         } else if (strcmp(it->name(), "conditions") == 0) {
-            std::cout << "conditions not supported" << std::endl;
-            exit(-1);
+            std::cerr << "conditions not supported" << std::endl;
+            exit(ErrorCode);
         } else if (strcmp(it->name(), "assignments") == 0) {
-            std::cout << "assignments not supported" << std::endl;
-            exit(-1);
+            std::cerr << "assignments not supported" << std::endl;
+            exit(ErrorCode);
         }
     }
     //Add transition to list

=== modified file 'PetriParse/QueryBinaryParser.cpp'
--- PetriParse/QueryBinaryParser.cpp	2018-04-17 12:13:30 +0000
+++ PetriParse/QueryBinaryParser.cpp	2018-05-12 15:14:12 +0000
@@ -276,8 +276,10 @@
     }
     else
     {
-        std::cout << t << std::endl;
+        std::cerr << "An error occurred parsing the binary input." << std::endl;
+        std::cerr << t << std::endl;
         assert(false);
+        exit(ErrorCode);
         return nullptr;
     }
 }

=== modified file 'PetriParse/QueryXMLParser.cpp'
--- PetriParse/QueryXMLParser.cpp	2018-03-19 16:36:16 +0000
+++ PetriParse/QueryXMLParser.cpp	2018-05-12 15:14:12 +0000
@@ -453,8 +453,10 @@
         }
         return std::make_shared<OrCondition>(conds);
     }
-    std::cout << elementName << std::endl;
+    std::cerr << "An error occurred while parsing the query." << std::endl;
+    std::cerr << elementName << std::endl;
     assert(false);
+    exit(ErrorCode);
     return nullptr;
 }
 

=== modified file 'VerifyPN.cpp'
--- VerifyPN.cpp	2018-04-25 11:46:50 +0000
+++ VerifyPN.cpp	2018-05-12 15:14:12 +0000
@@ -830,7 +830,7 @@
                             std::cerr << "Exception information: " << ba.what() << std::endl;
 
                             delete[] qm0;
-                            std::exit(3);
+                            std::exit(ErrorCode);
                         }
 
                         if(options.printstatistics)

